@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.405';
+our $VERSION = '0.406';
 
 =pod
 
@@ -193,6 +193,22 @@ sub indexes (&@)
     } 0 .. $#_;
 }
 
+sub lastres (&@)
+{
+    my $test = shift;
+    my $ix;
+    for ( $ix = $#_; $ix >= 0; $ix-- )
+    {
+        local *_ = \$_[$ix];
+        my $testval = $test->();
+
+        # Simulate $_ as alias
+        $_[$ix] = $_;
+        return $testval if $testval;
+    }
+    return undef;
+}
+
 sub lastval (&@)
 {
     my $test = shift;
@@ -209,6 +225,17 @@ sub lastval (&@)
     return undef;
 }
 
+sub firstres (&@)
+{
+    my $test = shift;
+    foreach (@_)
+    {
+        my $testval = $test->();
+	$testval and return $testval;
+    }
+    return undef;
+}
+
 sub firstval (&@)
 {
     my $test = shift;
